==> onos-yang-runtime-2.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tenodeaugment/te/TunnelTerminationPointKeys.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeaugment.te;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of tunnelTerminationPoint.
 */
public class TunnelTerminationPointKeys implements KeyInfo<DefaultTunnelTerminationPoint> {
    protected byte[] tunnelTpId;
    /**
     * Returns the attribute tunnelTpId.
     *
     * @return tunnelTpId value of tunnelTpId
     */
    public byte[] tunnelTpId() {
        return tunnelTpId;
    }

    /**
     * Sets the value to attribute tunnelTpId.
     *
     * @param tunnelTpId value of tunnelTpId
     */
    public void tunnelTpId(byte[] tunnelTpId) {
        this.tunnelTpId = tunnelTpId;
    }


    @Override
    public int hashCode() {
        return Objects.hash(tunnelTpId);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof TunnelTerminationPointKeys) {
            TunnelTerminationPointKeys other = (TunnelTerminationPointKeys) obj;
            return
                Objects.equals(tunnelTpId, other.tunnelTpId);
        }
        return false;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tenodeaugment/te/TunnelTerminationPointKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeaugment.te;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of tunnelTerminationPoint.
 */
public class TunnelTerminationPointKeys implements KeyInfo<DefaultTunnelTerminationPoint> {
    protected byte[] tunnelTpId;
    /**
     * Returns the attribute tunnelTpId.
     *
     * @return tunnelTpId value of tunnelTpId
     */
    public byte[] tunnelTpId() {
        return tunnelTpId;
    }

    /**
     * Sets the value to attribute tunnelTpId.
     *
     * @param tunnelTpId value of tunnelTpId
     */
    public void tunnelTpId(byte[] tunnelTpId) {
        this.tunnelTpId = tunnelTpId;
    }


    @Override
    public int hashCode() {
        return Objects.hash(tunnelTpId);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof TunnelTerminationPointKeys) {
            TunnelTerminationPointKeys other = (TunnelTerminationPointKeys) obj;
            return
                Objects.deepEquals(tunnelTpId, other.tunnelTpId);
        }
        return false;
    }
}
